## See LICENSE for license info
from distutils.core import setup
setup(name="growlpy",
      description="Python bindings for the growl notification system",
      author="Rotem Yaari",
      author_email="vmalloc@gmail.com",
      version="0.11",
      packages=["growl"])
